summaryrefslogtreecommitdiff
path: root/gtk/gtkstyleproperties.c
diff options
context:
space:
mode:
authorBenjamin Otte <otte@redhat.com>2011-12-29 02:28:32 +0100
committerBenjamin Otte <otte@redhat.com>2012-01-09 18:37:50 +0100
commitaa4925480dc783faddca9adf9d0f4d6bd96c066e (patch)
treeaa27c8f7d7799cc31b062d5988a37c2f65037f75 /gtk/gtkstyleproperties.c
parent4d15186e6756e8e757bc30686e7a02433e0291f7 (diff)
downloadgtk+-aa4925480dc783faddca9adf9d0f4d6bd96c066e.tar.gz
styleproperty: Pass initial value explicitly
Diffstat (limited to 'gtk/gtkstyleproperties.c')
-rw-r--r--gtk/gtkstyleproperties.c4
1 files changed, 3 insertions, 1 deletions
diff --git a/gtk/gtkstyleproperties.c b/gtk/gtkstyleproperties.c
index f2b6b7d23c..26a966563b 100644
--- a/gtk/gtkstyleproperties.c
+++ b/gtk/gtkstyleproperties.c
@@ -34,6 +34,7 @@
#include "gtkcsstypesprivate.h"
#include "gtkborderimageprivate.h"
+#include "gtkprivatetypebuiltins.h"
#include "gtkstylepropertyprivate.h"
#include "gtkstyleproviderprivate.h"
#include "gtkintl.h"
@@ -537,9 +538,10 @@ _gtk_style_properties_set_property_by_property (GtkStyleProperties *props,
if (style_prop->pspec->value_type == GDK_TYPE_RGBA ||
style_prop->pspec->value_type == GDK_TYPE_COLOR)
{
/* Allow GtkSymbolicColor as well */
g_return_if_fail (value_type == GDK_TYPE_RGBA ||
value_type == GDK_TYPE_COLOR ||
+ value_type == GTK_TYPE_CSS_SPECIAL_VALUE ||
value_type == GTK_TYPE_SYMBOLIC_COLOR);
}
else if (style_prop->pspec->value_type == CAIRO_GOBJECT_TYPE_PATTERN)
@@ -537,9 +538,10 @@ _gtk_style_properties_set_property_by_property (GtkStyleProperties *props,
style_prop->pspec->value_type == GDK_TYPE_COLOR)
{
- /* Allow GtkSymbolicColor as well */
+ /* Allow GtkSymbolicColor and special values as well */
g_return_if_fail (value_type == GDK_TYPE_RGBA ||
value_type == GDK_TYPE_COLOR ||